@@ -2,9 +2,8 @@ package Pod::WikiDoc;
 use strict;
 use warnings;
 # ABSTRACT: Generate Pod from inline wiki style text
-our $VERSION = '0.20'; # VERSION
 
-$Pod::WikiDoc::VERSION ||= '999';
+our $VERSION = '0.21';
 
 use 5.006;
 use Carp;
@@ -16,11 +15,114 @@ use Pod::WikiDoc::Parser;
 # PREAMBLE DOCUMENTATION
 #--------------------------------------------------------------------------#
 
+#pod =begin wikidoc
+#pod
+#pod = SYNOPSIS
+#pod
+#pod In a source file, Pod format-block style:
+#pod     =begin wikidoc
+#pod
+#pod     = POD FORMAT-BLOCK STYLE
+#pod
+#pod     Write documentation with *bold*, ~italic~ or {code}
+#pod     markup.  Create a link to [Pod::WikiDoc].
+#pod     Substitute for user-defined %%KEYWORD%%.
+#pod
+#pod         Indent for verbatim paragraphs
+#pod
+#pod     * bullet
+#pod     * point
+#pod     * list
+#pod
+#pod     0 sequentially
+#pod     0 numbered
+#pod     0 list
+#pod
+#pod     =end wikidoc
+#pod
+#pod In a source file, wikidoc comment-block style:
+#pod     ### = WIKIDOC COMMENT-BLOCK STYLE
+#pod     ###
+#pod     ### Optionally, [Pod::WikiDoc] can extract from
+#pod     ### specially-marked comment blocks
+#pod
+#pod Generate Pod from wikidoc, programmatically:
+#pod     use Pod::WikiDoc;
+#pod     my $parser = Pod::WikiDoc->new( {
+#pod         comment_blocks => 1,
+#pod         keywords => { KEYWORD => "foo" },
+#pod     } );
+#pod     $parser->filter(
+#pod         { input => "my_module.pm", output => "my_module.pod" }
+#pod     );
+#pod
+#pod Generate Pod from wikidoc, via command line:
+#pod     $ wikidoc -c my_module.pm my_module.pod
+#pod
+#pod = DESCRIPTION
+#pod
+#pod Pod works well, but writing it can be time-consuming and tedious.  For example,
+#pod commonly used layouts like lists require numerous lines of text to make just
+#pod a couple of simple points.  An alternative approach is to write documentation
+#pod in a wiki-text shorthand (referred to here as ~wikidoc~) and use Pod::WikiDoc
+#pod to extract it and convert it into its corresponding Pod as a separate {.pod}
+#pod file.
+#pod
+#pod Documentation written in wikidoc may be embedded in Pod format blocks, or,
+#pod optionally, in specially marked comment blocks.  Wikidoc uses simple text-based
+#pod markup like wiki websites to indicate formatting and links.  (See
+#pod [/WIKIDOC MARKUP], below.)
+#pod
+#pod Pod::WikiDoc processes text files (or text strings) by extracting both
+#pod existing Pod and wikidoc, converting the wikidoc to Pod, and then writing
+#pod the combined document back to a file or standard output.
+#pod
+#pod Summary of major features of Pod::WikiDoc:
+#pod
+#pod * Extracts and converts wikidoc from Pod format blocks or special
+#pod wikidoc comment blocks
+#pod * Extracts and preserves existing Pod
+#pod * Provides bold, italic, code, and link markup
+#pod * Substitutes user-defined keywords
+#pod * Automatically converts special symbols in wikidoc to their
+#pod Pod escape equivalents, e.g. \E\<lt\>, \E\<gt\>
+#pod * Preserves other Pod escape sequences, e.g. \E\<euro\>
+#pod
+#pod In addition, Pod::WikiDoc provides a command-line utility, [wikidoc],
+#pod to simplify wikidoc translation.
+#pod
+#pod See the [Pod::WikiDoc::Cookbook] for more detailed usage examples,
+#pod including how to automate {.pod} generation when using [Module::Build].
+#pod
+#pod = INTERFACE
+#pod
+#pod =end wikidoc
+#pod
+#pod =cut
 
 #--------------------------------------------------------------------------#
 # PUBLIC METHODS
 #--------------------------------------------------------------------------#
 
+#pod =begin wikidoc
+#pod
+#pod == {new}
+#pod
+#pod     $parser = Pod::WikiDoc->new( \%args );
+#pod
+#pod Constructor for a new Pod::WikiDoc object.  It takes a single, optional
+#pod argument: a hash reference with the following optional keys:
+#pod
+#pod * {comment_blocks}: if true, Pod::WikiDoc will scan for wikidoc in comment
+#pod blocks.  Default is false.
+#pod * {comment_prefix_length}: the number of leading sharp (#) symbols to
+#pod denote a comment block.  Default is 3.
+#pod * {keywords}: a hash reference with keywords and values for keyword
+#pod substitution
+#pod
+#pod =end wikidoc
+#pod
+#pod =cut
 
 my %default_args = (
     comment_blocks         => 0,
@@ -52,6 +154,20 @@ sub new {
     return bless $self, $class;
 }
 
+#pod =begin wikidoc
+#pod
+#pod == {convert}
+#pod
+#pod     my $pod_text = $parser->convert( $input_text );
+#pod
+#pod Given a string with valid Pod and/or wikidoc markup, filter/translate it to
+#pod Pod.  This is really just a wrapper around {filter} for working with
+#pod strings rather than files, and provides similar behavior, including adding
+#pod a 'Generated by' header.
+#pod
+#pod =end wikidoc
+#pod
+#pod =cut
 
 sub convert {
     my ($self, $input_string) = @_;
@@ -66,6 +182,27 @@ sub convert {
     return ${ $output_fh->string_ref() };
 }
 
+#pod =begin wikidoc
+#pod
+#pod == {filter}
+#pod
+#pod     $parser->filter( \%args );
+#pod
+#pod Filters from an input file for Pod and wikidoc, translating it to Pod
+#pod and writing it to an output file.  The output file will be prefixed with
+#pod a 'Generated by' comment with the version of Pod::WikiDoc and timestamp,
+#pod as required by [perlpodspec].
+#pod
+#pod {filter} takes a single, optional argument: a hash reference with
+#pod the following optional keys:
+#pod
+#pod * {input}: a filename or filehandle to read from. Defaults to STDIN.
+#pod * {output}: a filename or filehandle to write to.  If given a filename
+#pod and the file already exists, it will be clobbered. Defaults to STDOUT.
+#pod
+#pod =end wikidoc
+#pod
+#pod =cut
 
 sub filter {
     my ( $self, $args_ref ) = @_;
@@ -116,6 +253,22 @@ sub filter {
     return;
 }
 
+#pod =begin wikidoc
+#pod
+#pod == {format}
+#pod
+#pod     my $pod_text = $parser->format( $wiki_text );
+#pod
+#pod Given a string with valid Pod and/or wikidoc markup, filter/translate it to
+#pod Pod. Unlike {convert}, no 'Generated by' comment is added.  This
+#pod function is used internally by Pod::WikiDoc, but is being made available
+#pod as a public method for users who want more granular control of the
+#pod translation process or who want to convert wikidoc to Pod for other
+#pod creative purposes using the Pod::WikiDoc engine.
+#pod
+#pod =end wikidoc
+#pod
+#pod =cut
 
 sub format { ## no critic
     my ($self, $wikitext) = @_;
@@ -590,16 +743,19 @@ sub _wiki2pod {
 
 1; #this line is important and will help the module return a true value
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Pod::WikiDoc - Generate Pod from inline wiki style text
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -1014,14 +1170,14 @@ C<<< dist_abstract >>> option.
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through the issue tracker
-at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-WikiDoc>.
+at L<https://github.com/dagolden/pod-wikidoc/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -1037,16 +1193,18 @@ L<https://github.com/dagolden/pod-wikidoc>
 
 David A Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords James E Keenan
+
+James E Keenan <jkeenan@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by David A Golden.
+This software is Copyright (c) 2017 by David A Golden.
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
-
-
-__END__
-
